package de.intevation.gnv.state.describedata;

import java.io.Serializable;

/**
 * This interface defines some methods to retrieve a key-value pair, a state
 * this data belongs to and a boolean property, if this data have been selected.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public interface KeyValueDescibeData extends Serializable {

    /**
     * Returns the key of this data object.
     *
     * @return the key.
     */
    public String getKey();

    /**
     * Returns the value of this data object.
     *
     * @return the value.
     */
    public String getValue();

    /**
     * Returns the state of this data object.
     *
     * @return the state.
     */
    public String getState();

    /**
     * Returns a boolean which defines, if this data pair has been selected or
     * not.
     *
     * @return true, if this pair has been selected - otherwise false.
     */
    public boolean isSelected();

    /**
     * Method to change the selection of this data object.
     *
     * @param selected Set this value to true, if you want to select this data
     * object - set it to false, if you want to unselect it.
     */
    public void setSelected(boolean selected);
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :